@@ -2,7 +2,7 @@ package Devel::ebug::Plugin::Eval;
 use strict;
 use warnings;
 use base qw(Exporter);
-our @EXPORT = qw(eval);
+our @EXPORT = qw(eval yaml);
 
 # eval
 sub eval {
@@ -14,4 +14,14 @@ sub eval {
   return $response->{eval};
 }
 
+# yaml
+sub yaml {
+  my($self, $yaml) = @_;
+  my $response = $self->talk({
+    command => "yaml",
+    yaml    => $yaml,
+  });
+  return $response->{yaml};
+}
+
 1;
